@@ -1,2 +1,5 @@
 import pkg_resources
 __version__ = pkg_resources.get_distribution('gtFrame').version
+
+# GLOBAL DEFAULT TOLERANCE
+DEFAULT_RTOL = 1e-12
